@@ -1,7 +1,7 @@
 /*
  *  editdlg.cpp  -  dialog to create or modify an alarm or alarm template
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2021 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -97,10 +97,10 @@ EditAlarmDlg* EditAlarmDlg::create(bool Template, Type type, QWidget* parent, Ge
     return nullptr;
 }
 
-EditAlarmDlg* EditAlarmDlg::create(bool Template, const KAEvent* event, bool newAlarm, QWidget* parent,
+EditAlarmDlg* EditAlarmDlg::create(bool Template, const KAEvent& event, bool newAlarm, QWidget* parent,
                                    GetResourceType getResource, bool readOnly)
 {
-    switch (event->actionTypes())
+    switch (event.actionTypes())
     {
         case KAEvent::ACT_COMMAND:  return new EditCommandAlarmDlg(Template, event, newAlarm, parent, getResource, readOnly);
         case KAEvent::ACT_DISPLAY_COMMAND:
@@ -119,7 +119,7 @@ EditAlarmDlg* EditAlarmDlg::create(bool Template, const KAEvent* event, bool new
 * Parameters:
 *   Template = true to edit/create an alarm template
 *            = false to edit/create an alarm.
-*   event   != to initialise the dialog to show the specified event's data.
+*   event    to initialise the dialog to show the specified event's data.
 */
 EditAlarmDlg::EditAlarmDlg(bool Template, KAEvent::SubAction action, QWidget* parent, GetResourceType getResource)
     : QDialog(parent)
@@ -129,15 +129,15 @@ EditAlarmDlg::EditAlarmDlg(bool Template, KAEvent::SubAction action, QWidget* pa
     , mDesiredReadOnly(false)
     , mReadOnly(false)
 {
-    init(nullptr, getResource);
+    init(KAEvent(), getResource);
     mWindowList.append(this);
 }
 
-EditAlarmDlg::EditAlarmDlg(bool Template, const KAEvent* event, bool newAlarm, QWidget* parent,
+EditAlarmDlg::EditAlarmDlg(bool Template, const KAEvent& event, bool newAlarm, QWidget* parent,
                            GetResourceType getResource, bool readOnly)
     : QDialog(parent)
-    , mAlarmType(event->actionSubType())
-    , mEventId(newAlarm ? QString() : event->id())
+    , mAlarmType(event.actionSubType())
+    , mEventId(newAlarm ? QString() : event.id())
     , mTemplate(Template)
     , mNewAlarm(newAlarm)
     , mDesiredReadOnly(readOnly)
@@ -147,14 +147,14 @@ EditAlarmDlg::EditAlarmDlg(bool Template, const KAEvent* event, bool newAlarm, Q
     mWindowList.append(this);
 }
 
-void EditAlarmDlg::init(const KAEvent* event, GetResourceType getResource)
+void EditAlarmDlg::init(const KAEvent& event, GetResourceType getResource)
 {
     switch (getResource)
     {
         case RES_USE_EVENT_ID:
-            if (event)
+            if (event.isValid())
             {
-                mResourceEventId = event->id();
+                mResourceEventId = event.id();
                 mUseResourceEventId = true;
                 break;
             }
@@ -171,14 +171,14 @@ void EditAlarmDlg::init(const KAEvent* event, GetResourceType getResource)
     }
 }
 
-void EditAlarmDlg::init(const KAEvent* event)
+void EditAlarmDlg::init(const KAEvent& event)
 {
     setObjectName(mTemplate ? QStringLiteral("TemplEditDlg") : QStringLiteral("EditDlg"));    // used by LikeBack
     QString caption;
     if (mReadOnly)
         caption = mTemplate ? i18nc("@title:window", "Alarm Template [read-only]")
-                : event->expired() ? i18nc("@title:window", "Archived Alarm [read-only]")
-                                   : i18nc("@title:window", "Alarm [read-only]");
+                : event.expired() ? i18nc("@title:window", "Archived Alarm [read-only]")
+                                  : i18nc("@title:window", "Alarm [read-only]");
     else
         caption = type_caption();
     setWindowTitle(caption);
@@ -215,25 +215,25 @@ void EditAlarmDlg::init(const KAEvent* event)
     if (mButtonBox->button(QDialogButtonBox::Ok))
         mButtonBox->button(QDialogButtonBox::Ok)->setWhatsThis(i18nc("@info:whatsthis", "Schedule the alarm at the specified time."));
 
-    auto* mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     mTabs = new QTabWidget(this);
     mainLayout->addWidget(mTabs);
     mTabScrollGroup = new StackedScrollGroup(this, mTabs);
 
-    auto* mainScroll = new StackedScrollWidget(mTabScrollGroup);
+    auto mainScroll = new StackedScrollWidget(mTabScrollGroup);
     mTabs->addTab(mainScroll, i18nc("@title:tab", "Alarm"));
     mMainPageIndex = 0;
-    auto* mainPage = new PageFrame(mainScroll);
+    auto mainPage = new PageFrame(mainScroll);
     mainScroll->setWidget(mainPage);   // mainPage becomes the child of mainScroll
     connect(mainPage, &PageFrame::shown, this, &EditAlarmDlg::slotShowMainPage);
-    auto* topLayout = new QVBoxLayout(mainPage);
+    auto topLayout = new QVBoxLayout(mainPage);
 
     // Recurrence tab
-    auto* recurScroll = new StackedScrollWidget(mTabScrollGroup);
+    auto recurScroll = new StackedScrollWidget(mTabScrollGroup);
     mTabs->addTab(recurScroll, QString());
     mRecurPageIndex = 1;
     QFrame* recurTab = new QFrame;
-    auto* recurTabLayout = new QVBoxLayout();
+    auto recurTabLayout = new QVBoxLayout();
     recurTab->setLayout(recurTabLayout);
     recurScroll->setWidget(recurTab);   // recurTab becomes the child of recurScroll
     mRecurrenceEdit = new RecurrenceEdit(mReadOnly);
@@ -248,7 +248,7 @@ void EditAlarmDlg::init(const KAEvent* event)
     {
         // Alarm/template name
         QFrame* frame = new QFrame;
-        auto* box = new QHBoxLayout();
+        auto box = new QHBoxLayout();
         frame->setLayout(box);
         box->setContentsMargins(0, 0, 0, 0);
         QLabel* label = new QLabel(mTemplate ? i18nc("@label:textbox", "Template name:") : i18nc("@label:textbox", "Alarm name:"));
@@ -268,7 +268,7 @@ void EditAlarmDlg::init(const KAEvent* event)
     // Controls specific to the alarm type
     QGroupBox* actionBox = new QGroupBox(i18nc("@title:group", "Action"), mainPage);
     topLayout->addWidget(actionBox, 1);
-    auto* layout = new QVBoxLayout(actionBox);
+    auto layout = new QVBoxLayout(actionBox);
 
     type_init(actionBox, layout);
 
@@ -277,7 +277,7 @@ void EditAlarmDlg::init(const KAEvent* event)
         // Deferred date/time: visible only for a deferred recurring event.
         mDeferGroup = new QGroupBox(i18nc("@title:group", "Deferred Alarm"), mainPage);
         topLayout->addWidget(mDeferGroup);
-        auto* hlayout = new QHBoxLayout(mDeferGroup);
+        auto hlayout = new QHBoxLayout(mDeferGroup);
         QLabel* label = new QLabel(i18nc("@label", "Deferred to:"), mDeferGroup);
         label->setFixedSize(label->sizeHint());
         hlayout->addWidget(label);
@@ -292,7 +292,7 @@ void EditAlarmDlg::init(const KAEvent* event)
 //??        mDeferGroup->addSpace(0);
     }
 
-    auto* hlayout = new QHBoxLayout();
+    auto hlayout = new QHBoxLayout();
     hlayout->setContentsMargins(0, 0, 0, 0);
     topLayout->addLayout(hlayout);
 
@@ -301,7 +301,7 @@ void EditAlarmDlg::init(const KAEvent* event)
     {
         QGroupBox* templateTimeBox = new QGroupBox(i18nc("@title:group", "Time"), mainPage);
         topLayout->addWidget(templateTimeBox);
-        auto* grid = new QGridLayout(templateTimeBox);
+        auto grid = new QGridLayout(templateTimeBox);
         mTemplateTimeGroup = new ButtonGroup(templateTimeBox);
         connect(mTemplateTimeGroup, &ButtonGroup::buttonSet, this, &EditAlarmDlg::slotTemplateTimeType);
         connect(mTemplateTimeGroup, &ButtonGroup::buttonSet, this, &EditAlarmDlg::contentsChanged);
@@ -315,7 +315,7 @@ void EditAlarmDlg::init(const KAEvent* event)
         grid->addWidget(mTemplateDefaultTime, 0, 0, Qt::AlignLeft);
 
         QWidget* box = new QWidget(templateTimeBox);
-        auto* layout = new QHBoxLayout(box);
+        auto layout = new QHBoxLayout(box);
         layout->setContentsMargins(0, 0, 0, 0);
         mTemplateUseTime = new RadioButton(i18nc("@option:radio", "Time:"), box);
         mTemplateUseTime->setFixedSize(mTemplateUseTime->sizeHint());
@@ -377,7 +377,7 @@ void EditAlarmDlg::init(const KAEvent* event)
     mMoreOptions = new QFrame(mainPage);
     mMoreOptions->setFrameStyle(QFrame::NoFrame);
     topLayout->addWidget(mMoreOptions);
-    auto* moreLayout = new QVBoxLayout(mMoreOptions);
+    auto moreLayout = new QVBoxLayout(mMoreOptions);
     moreLayout->setContentsMargins(0, 0, 0, 0);
 
     // Reminder
@@ -434,7 +434,7 @@ void EditAlarmDlg::init(const KAEvent* event)
     if (!mNewAlarm)
     {
         // Save the initial state of all controls so that we can later tell if they have changed
-        saveState((event && (mTemplate || !event->isTemplate())) ? event : nullptr);
+        saveState((event.isValid() && (mTemplate || !event.isTemplate())) ? &event : nullptr);
         contentsChanged();    // enable/disable OK button
     }
 
@@ -471,7 +471,7 @@ int EditAlarmDlg::instanceCount()
 /******************************************************************************
 * Initialise the dialog controls from the specified event.
 */
-void EditAlarmDlg::initValues(const KAEvent* event)
+void EditAlarmDlg::initValues(const KAEvent& event)
 {
     setReadOnly(mDesiredReadOnly);
 
@@ -480,42 +480,42 @@ void EditAlarmDlg::initValues(const KAEvent* event)
     mExpiredRecurrence = false;
     mLateCancel->showAutoClose(false);
     bool deferGroupVisible = false;
-    if (event)
+    if (event.isValid())
     {
         // Set the values to those for the specified event
         if (mName)
-            mName->setText(event->name());
-        bool recurs = event->recurs();
-        if ((recurs || event->repetition())  &&  !mTemplate  &&  event->deferred())
+            mName->setText(event.name());
+        bool recurs = event.recurs();
+        if ((recurs || event.repetition())  &&  !mTemplate  &&  event.deferred())
         {
             deferGroupVisible = true;
-            mDeferDateTime = event->deferDateTime();
+            mDeferDateTime = event.deferDateTime();
             mDeferTimeLabel->setText(mDeferDateTime.formatLocale());
             mDeferGroup->show();
         }
         if (mTemplate)
         {
             // Editing a template
-            int afterTime = event->isTemplate() ? event->templateAfterTime() : -1;
+            int afterTime = event.isTemplate() ? event.templateAfterTime() : -1;
             bool noTime   = !afterTime;
-            bool useTime  = !event->mainDateTime().isDateOnly();
+            bool useTime  = !event.mainDateTime().isDateOnly();
             RadioButton* button = noTime          ? mTemplateDefaultTime :
                                   (afterTime > 0) ? mTemplateUseTimeAfter :
                                   useTime         ? mTemplateUseTime : mTemplateAnyTime;
             button->setChecked(true);
             mTemplateTimeAfter->setValue(afterTime > 0 ? afterTime : 1);
             if (!noTime && useTime)
-                mTemplateTime->setValue(event->mainDateTime().kDateTime().time());
+                mTemplateTime->setValue(event.mainDateTime().kDateTime().time());
             else
                 mTemplateTime->setValue(0);
         }
         else
         {
-            if (event->isTemplate())
+            if (event.isTemplate())
             {
                 // Initialising from an alarm template: use current date
                 const KADateTime now = KADateTime::currentDateTime(Preferences::timeSpec());
-                int afterTime = event->templateAfterTime();
+                int afterTime = event.templateAfterTime();
                 if (afterTime >= 0)
                 {
                     mTimeWidget->setDateTime(now.addSecs(afterTime * 60));
@@ -523,7 +523,7 @@ void EditAlarmDlg::initValues(const KAEvent* event)
                 }
                 else
                 {
-                    KADateTime dt = event->startDateTime().kDateTime();
+                    KADateTime dt = event.startDateTime().kDateTime();
                     dt.setTimeSpec(Preferences::timeSpec());
                     QDate d = now.date();
                     if (!dt.isDateOnly()  &&  now.time() >= dt.time())
@@ -534,27 +534,27 @@ void EditAlarmDlg::initValues(const KAEvent* event)
             }
             else
             {
-                mExpiredRecurrence = recurs && event->mainExpired();
-                mTimeWidget->setDateTime(recurs || event->category() == CalEvent::ARCHIVED ? event->startDateTime()
-                                         : event->mainExpired() ? event->deferDateTime() : event->mainDateTime());
+                mExpiredRecurrence = recurs && event.mainExpired();
+                mTimeWidget->setDateTime(recurs || event.category() == CalEvent::ARCHIVED ? event.startDateTime()
+                                         : event.mainExpired() ? event.deferDateTime() : event.mainDateTime());
             }
         }
 
-        KAEvent::SubAction action = event->actionSubType();
+        KAEvent::SubAction action = event.actionSubType();
         AlarmText altext;
-        if (event->commandScript())
-            altext.setScript(event->cleanText());
+        if (event.commandScript())
+            altext.setScript(event.cleanText());
         else
-            altext.setText(event->cleanText());
+            altext.setText(event.cleanText());
         setAction(action, altext);
 
-        mLateCancel->setMinutes(event->lateCancel(), event->startDateTime().isDateOnly(),
+        mLateCancel->setMinutes(event.lateCancel(), event.startDateTime().isDateOnly(),
                                 TimePeriod::HoursMinutes);
         if (mShowInKorganizer)
-            mShowInKorganizer->setChecked(event->copyToKOrganizer());
+            mShowInKorganizer->setChecked(event.copyToKOrganizer());
         type_initValues(event);
-        mRecurrenceEdit->set(*event);   // must be called after mTimeWidget is set up, to ensure correct date-only enabling
-        mTabs->setTabText(mRecurPageIndex, recurText(*event));
+        mRecurrenceEdit->set(event);   // must be called after mTimeWidget is set up, to ensure correct date-only enabling
+        mTabs->setTabText(mRecurPageIndex, recurText(event));
     }
     else
     {
@@ -571,7 +571,7 @@ void EditAlarmDlg::initValues(const KAEvent* event)
         mLateCancel->setMinutes((Preferences::defaultLateCancel() ? 1 : 0), false, TimePeriod::HoursMinutes);
         if (mShowInKorganizer)
             mShowInKorganizer->setChecked(Preferences::defaultCopyToKOrganizer());
-        type_initValues(nullptr);
+        type_initValues(KAEvent());
         mRecurrenceEdit->setDefaults(defaultTime);   // must be called after mTimeWidget is set up, to ensure correct date-only enabling
         slotRecurFrequencyChange();      // update the Recurrence text
     }
@@ -597,6 +597,11 @@ void EditAlarmDlg::setName(const QString& name)
 void EditAlarmDlg::setTime(const DateTime& start)
 {
     mTimeWidget->setDateTime(start);
+    mTimeWidget->selectTimeFromNow(-1);    // select 'At date/time' option
+}
+KADateTime EditAlarmDlg::time() const
+{
+    return mTimeWidget->getDateTime(nullptr, false, false);
 }
 void EditAlarmDlg::setRecurrence(const KARecurrence& recur, const KCalendarCore::Duration& subRepeatInterval, int subRepeatCount)
 {
@@ -861,7 +866,7 @@ void EditAlarmDlg::showEvent(QShowEvent* se)
     if (theApp()->needWindowFocusFix())
     {
         QApplication::setActiveWindow(this);
-        QTimer::singleShot(0, this, &EditAlarmDlg::focusFixTimer);
+        QTimer::singleShot(0, this, &EditAlarmDlg::focusFixTimer);   //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
     }
 }
 
@@ -878,7 +883,7 @@ void EditAlarmDlg::focusFixTimer()
     &&  QApplication::focusWidget()->window() != this)
     {
         QApplication::setActiveWindow(this);
-        QTimer::singleShot(0, this, &EditAlarmDlg::focusFixTimer);
+        QTimer::singleShot(0, this, &EditAlarmDlg::focusFixTimer);   //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
     }
 }
 
@@ -1206,7 +1211,7 @@ void EditAlarmDlg::slotHelp()
     if (dlg->exec() == QDialog::Accepted)
     {
         KAEvent event = dlg->selectedTemplate();
-        initValues(&event);
+        initValues(event);
     }
 }
 
@@ -1245,7 +1250,7 @@ void EditAlarmDlg::showOptions(bool more)
     type_showOptions(more);
     mRecurrenceEdit->showMoreOptions(more);
     mShowingMore = more;
-    QTimer::singleShot(0, this, &EditAlarmDlg::slotResize);
+    QTimer::singleShot(0, this, &EditAlarmDlg::slotResize);   //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
 }
 
 /******************************************************************************
@@ -1325,7 +1330,7 @@ void EditAlarmDlg::slotShowMainPage()
     else
     {
         // Set scroll position to top, since it otherwise jumps randomly
-        auto* main = static_cast<StackedScrollWidget*>(mTabs->widget(0));
+        auto main = static_cast<StackedScrollWidget*>(mTabs->widget(0));
         main->verticalScrollBar()->setValue(0);
     }
     if (mTimeWidget)
