@@ -660,7 +660,7 @@ QString ResourceDataModelBase::alarmTimeText(const DateTime& dateTime, char lead
 
     if (!dateTime.isValid())
         return i18nc("@info Alarm never occurs", "Never");
-    if (!leadingZeroesChecked  &&  QApplication::isLeftToRight())    // don't try to align right-to-left languages
+    if (!leadingZeroesChecked)
     {
         // Check whether the day number and/or hour have no leading zeroes, if
         // they are at the start of the date/time. If no leading zeroes, they
@@ -668,75 +668,74 @@ QString ResourceDataModelBase::alarmTimeText(const DateTime& dateTime, char lead
         // can be aligned with each other.
         // Note that if leading zeroes are not included in other components, no
         // alignment will be attempted.
+
+        // Check the date format. 'dd' provides leading zeroes; single 'd'
+        // provides no leading zeroes.
         QLocale locale;
+        dateFormat = locale.dateFormat(QLocale::ShortFormat);
+
+        // Check the time format.
+        // Remove all but hours, minutes and AM/PM, since alarms are on minute
+        // boundaries. Preceding separators are also removed.
+        timeFormat = locale.timeFormat(QLocale::ShortFormat);
+        for (int del = 0, predel = 0, c = 0;  c < timeFormat.size();  ++c)
         {
-            // Check the date format. 'dd' provides leading zeroes; single 'd'
-            // provides no leading zeroes.
-            dateFormat = locale.dateFormat(QLocale::ShortFormat);
-        }
-        {
-            // Check the time format.
-            // Remove all but hours, minutes and AM/PM, since alarms are on minute
-            // boundaries. Preceding separators are also removed.
-            timeFormat = locale.timeFormat(QLocale::ShortFormat);
-            for (int del = 0, predel = 0, c = 0;  c < timeFormat.size();  ++c)
+            char ch = timeFormat.at(c).toLatin1();
+            switch (ch)
             {
-                char ch = timeFormat.at(c).toLatin1();
-                switch (ch)
-                {
-                    case 'H':
-                    case 'h':
-                    case 'm':
-                    case 'a':
-                    case 'A':
-                        if (predel == 1)
-                        {
-                            timeFormat.remove(del, c - del);
-                            c = del;
-                        }
-                        del = c + 1;   // start deleting from the next character
-                        if ((ch == 'A'  &&  del < timeFormat.size()  &&  timeFormat.at(del).toLatin1() == 'P')
-                        ||  (ch == 'a'  &&  del < timeFormat.size()  &&  timeFormat.at(del).toLatin1() == 'p'))
-                            ++c, ++del;
-                        predel = -1;
-                        break;
-
-                    case 's':
-                    case 'z':
-                    case 't':
-                        timeFormat.remove(del, c + 1 - del);
-                        c = del - 1;
-                        if (!predel)
-                            predel = 1;
-                        break;
-
-                    default:
-                        break;
-                }
-            }
-
-            // 'HH' and 'hh' provide leading zeroes; single 'H' or 'h' provide no
-            // leading zeroes.
-            int i = timeFormat.indexOf(QRegExp(QLatin1String("[hH]")));
-            int first = timeFormat.indexOf(QRegExp(QLatin1String("[hHmaA]")));
-            if (i >= 0  &&  i == first  &&  (i == timeFormat.size() - 1  ||  timeFormat.at(i) != timeFormat.at(i + 1)))
-            {
-                timeFullFormat = timeFormat;
-                timeFullFormat.insert(i, timeFormat.at(i));
-                // Find index to hour in formatted times
-                const QTime t(1,30,30);
-                const QString nozero = t.toString(timeFormat);
-                const QString zero   = t.toString(timeFullFormat);
-                for (int i = 0; i < nozero.size(); ++i)
-                    if (nozero[i] != zero[i])
+                case 'H':
+                case 'h':
+                case 'm':
+                case 'a':
+                case 'A':
+                    if (predel == 1)
                     {
-                        hourOffset = i;
-                        break;
+                        timeFormat.remove(del, c - del);
+                        c = del;
                     }
+                    del = c + 1;   // start deleting from the next character
+                    if ((ch == 'A'  &&  del < timeFormat.size()  &&  timeFormat.at(del).toLatin1() == 'P')
+                    ||  (ch == 'a'  &&  del < timeFormat.size()  &&  timeFormat.at(del).toLatin1() == 'p'))
+                        ++c, ++del;
+                    predel = -1;
+                    break;
+
+                case 's':
+                case 'z':
+                case 't':
+                    timeFormat.remove(del, c + 1 - del);
+                    c = del - 1;
+                    if (!predel)
+                        predel = 1;
+                    break;
+
+                default:
+                    break;
             }
         }
+
+        // 'HH' and 'hh' provide leading zeroes; single 'H' or 'h' provide no
+        // leading zeroes.
+        int i = timeFormat.indexOf(QRegExp(QLatin1String("[hH]")));
+        int first = timeFormat.indexOf(QRegExp(QLatin1String("[hHmaA]")));
+        if (i >= 0  &&  i == first  &&  (i == timeFormat.size() - 1  ||  timeFormat.at(i) != timeFormat.at(i + 1)))
+        {
+            timeFullFormat = timeFormat;
+            timeFullFormat.insert(i, timeFormat.at(i));
+            // Find index to hour in formatted times
+            const QTime t(1,30,30);
+            const QString nozero = t.toString(timeFormat);
+            const QString zero   = t.toString(timeFullFormat);
+            for (int i = 0; i < nozero.size(); ++i)
+                if (nozero[i] != zero[i])
+                {
+                    hourOffset = i;
+                    break;
+                }
+        }
+
+        leadingZeroesChecked = true;
     }
-    leadingZeroesChecked = true;
 
     const KADateTime kdt = dateTime.effectiveKDateTime().toTimeSpec(Preferences::timeSpec());
     QString dateTimeText = kdt.date().toString(dateFormat);
@@ -746,7 +745,8 @@ QString ResourceDataModelBase::alarmTimeText(const DateTime& dateTime, char lead
         // Display the time of day if it's a date/time value, or if it's
         // a date-only value but it's in a different time zone
         dateTimeText += QLatin1Char(' ');
-        bool useFullFormat = leadingZero && !timeFullFormat.isEmpty();
+        // Don't try to align right-to-left languages...
+        const bool useFullFormat = QApplication::isLeftToRight() && leadingZero && !timeFullFormat.isEmpty();
         QString timeText = kdt.time().toString(useFullFormat ? timeFullFormat : timeFormat);
         if (useFullFormat  &&  leadingZero != '0'  &&  timeText.at(hourOffset) == QLatin1Char('0'))
             timeText[hourOffset] = QChar::fromLatin1(leadingZero);
@@ -770,7 +770,7 @@ QString ResourceDataModelBase::timeToAlarmText(const DateTime& dateTime)
         return i18nc("@info n days", "%1d", days);
     }
     int mins = (now.secsTo(dateTime.effectiveKDateTime()) + 59) / 60;
-    if (mins < 0)
+    if (mins <= 0)
         return QString();
     char minutes[3] = "00";
     minutes[0] = (mins%60) / 10 + '0';
